@@ -243,7 +243,7 @@ class StdPathHandler(FileSystemEventHandler,QWidget):
             if stdinit.current_board == current_boardn:
                 pass
             else:
-                upload_p = stdinit.stdenv + "/.platformio/platforms/" + platformnew + "/boards/" + current_boardn + ".json"
+                upload_p = stdinit.stdenv + "/.platformio/boards/"  + current_boardn + ".json"
                 if os.path.exists(upload_p):
                     stdinit.upload_meds.clear()
                     stdinit.current_board = current_boardn
@@ -260,17 +260,44 @@ class StdPathHandler(FileSystemEventHandler,QWidget):
                     except:
                         stdinit.upload_meds.append("Default")
 
-
                     if stdinit.current_upload_m == None:
-                        if upload_medd=="Default":
+                        if upload_medd == "Default":
                             stdinit.current_upload_m = upload_medd
                         else:
                             stdinit.pro_conf.set(stdinit.pro_conf.sections()[i], "upload_protocol", upload_medd)
                             stdinit.current_upload_m = upload_medd
                             stdinit.pro_conf.write(open(init_path, 'w'))
-
                     stdinit.std_signal_gobal.std_upload_list_change()
-                pass
+                else:
+                    upload_p = stdinit.stdenv + "/.platformio/platforms/" + platformnew + "/boards/" + current_boardn + ".json"
+                    if os.path.exists(upload_p):
+                        stdinit.upload_meds.clear()
+                        stdinit.current_board = current_boardn
+                        fo = open(upload_p, mode='r', encoding='UTF-8')
+                        st = fo.read()
+                        fo.close()
+                        psd = json.loads(st)
+                        try:
+                            upload_medd = psd["upload"]["protocol"]
+                        except:
+                            upload_medd = "Default"
+                        try:
+                            stdinit.upload_meds = psd["upload"]["protocols"]
+                        except:
+                            stdinit.upload_meds.append("Default")
+
+                        if stdinit.current_upload_m == None:
+                            if upload_medd == "Default":
+                                stdinit.current_upload_m = upload_medd
+                            else:
+                                stdinit.pro_conf.set(stdinit.pro_conf.sections()[i], "upload_protocol", upload_medd)
+                                stdinit.current_upload_m = upload_medd
+                                stdinit.pro_conf.write(open(init_path, 'w'))
+
+                        stdinit.std_signal_gobal.std_upload_list_change()
+                    pass
+
+
         except:
             stdinit.std_signal_gobal.stdprintln()
 
@@ -324,17 +351,8 @@ class StdPathHandler(FileSystemEventHandler,QWidget):
                             t1 = threading.Thread(target=self.tags_uploads, name=stdinit.project_name)
                             t1.setDaemon(True)
                             t1.start()  # File_tree_init
-
-
-
-
-
                             # platformnew = stdinit.pro_conf.get(stdinit.pro_conf.sections()[0], "platform")
-
-
                                     #
-
-
                         else:
                             stdinit.init_path = None
                     except:
@@ -391,11 +409,6 @@ class StdPathHandler(FileSystemEventHandler,QWidget):
             stdinit.std_signal_gobal.stdprintln()
             #print("Unexpected error:", sys.exc_info()[1])  # 错误内容
 
-
-
-
-
-
     def file_created(self, r_path):
         try:
             r_path = sorted(r_path, key=lambda i: len(i), reverse=False)
